# scab-python
python implementation of scab (stimulation controller for auditory bci)
  
You can find the document [here](http://pyscab.readthedocs.io/)
  
Author : Simon Kojima  
Guest Researcher at Donders Institue, Radboud University, Nijmegen, Netherlands  
Ph.D. Stundent at Shibaura Institue of Technology, Tokyo, Japan  
